@@ -1,21 +1,8 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2019 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef EMAIL_H
@@ -28,7 +15,11 @@
 #include <QSharedDataPointer>
 #include <QString>
 
-namespace KContacts {
+class EmailTest;
+
+namespace KContacts
+{
+class ParameterMap;
 
 /** @short Class that holds a Email for a contact.
  *  @since 4.14.5
@@ -37,6 +28,8 @@ class KCONTACTS_EXPORT Email
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Email &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Email &);
+    friend class VCardTool;
+    friend class ::EmailTest;
 
     Q_GADGET
     Q_PROPERTY(QString email READ mail WRITE setEmail)
@@ -54,16 +47,22 @@ public:
 
     ~Email();
 
-    typedef QVector<Email> List;
+    typedef QList<Email> List;
 
-    /** Email types. */
+    /**
+     * Email types.
+     * @see Type
+     */
     enum TypeFlag {
         Unknown = 0, /**< No or unknown email type is set. */
-        Home = 1,    /**< Personal email. */
-        Work = 2,    /**< Work email. */
-        Other = 4,   /**< Other email. */
+        Home = 1, /**< Personal email. */
+        Work = 2, /**< Work email. */
+        Other = 4, /**< Other email. */
     };
 
+    /**
+     * Stores a combination of #TypeFlag values.
+     */
     Q_DECLARE_FLAGS(Type, TypeFlag)
     Q_FLAG(Type)
 
@@ -94,16 +93,17 @@ public:
      */
     void setPreferred(bool preferred);
 
-    void setParameters(const QMap<QString, QStringList> &params);
-    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
-
     Q_REQUIRED_RESULT bool operator==(const Email &other) const;
     Q_REQUIRED_RESULT bool operator!=(const Email &other) const;
 
     Email &operator=(const Email &other);
 
     Q_REQUIRED_RESULT QString toString() const;
+
 private:
+    void setParams(const ParameterMap &params);
+    Q_REQUIRED_RESULT ParameterMap params() const;
+
     class Private;
     QSharedDataPointer<Private> d;
 };
@@ -114,6 +114,7 @@ KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Email &objec
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Email &object);
 }
-Q_DECLARE_METATYPE(KContacts::Email)
-Q_DECLARE_TYPEINFO(KContacts::Email, Q_MOVABLE_TYPE);
+
+Q_DECLARE_TYPEINFO(KContacts::Email, Q_RELOCATABLE_TYPE);
+
 #endif // EMAIL_H
